#
# spec file for package babl
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define debug_package_requires libbabl-0_1-0 = %{version}-%{release}
Name:           babl
Version:        0.1.46
Release:        lp150.1.1
Summary:        Dynamic Pixel Format Translation Library
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://gegl.org/babl/
Source:         http://ftp.gtk.org/pub/babl/0.1/%{name}-%{version}.tar.bz2
BuildRequires:  pkgconfig
# None of these is needed for standard build:
#BuildRequires:  inkscape ruby w3m

%description
babl is a dynamic, any to any, pixel format translation library.

It allows converting between different methods of storing pixels known
as pixel formats that have with different bitdepths and other data
representations, color models and component permutations.

A vocabulary to formulate new pixel formats from existing primitives is
provided as well as the framework to add new color models and data
types.

%package -n libbabl-0_1-0
Summary:        Dynamic Pixel Format Translation Library
Group:          System/Libraries

%description -n libbabl-0_1-0
babl is a dynamic, any to any, pixel format translation library.

It allows converting between different methods of storing pixels known
as pixel formats that have with different bitdepths and other data
representations, color models and component permutations.

A vocabulary to formulate new pixel formats from existing primitives is
provided as well as the framework to add new color models and data
types.

%package devel
Summary:        Dynamic Pixel Format Translation Library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libbabl-0_1-0 = %{version}

%description devel
babl is a dynamic, any to any, pixel format translation library.

It allows converting between different methods of storing pixels known
as pixel formats that have with different bitdepths and other data
representations, color models and component permutations.

A vocabulary to formulate new pixel formats from existing primitives is
provided as well as the framework to add new color models and data
types.

%prep
%setup -q

%build
%configure \
	--disable-static \
	%{nil}
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libbabl-0_1-0 -p /sbin/ldconfig
%postun -n libbabl-0_1-0 -p /sbin/ldconfig

%files -n libbabl-0_1-0
%license COPYING
%doc NEWS
%{_libdir}/*.so.*
%{_libdir}/babl-0.1/

%files devel
%doc AUTHORS README TODO
%{_includedir}/babl-0.1/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Apr 18 2018 bjorn.lie@gmail.com
- Update to version 0.1.46:
  + Added extensions with more coverage for u32, half and other
    utilit fast paths.
  + Improving fast path coverage.
* Wed Mar  7 2018 bjorn.lie@gmail.com
- Update to version 0.1.44:
  + Fix bug in custom primaries/ICC fast paths, improve meson
    build.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jan 26 2018 bjorn.lie@gmail.com
- Update to version 0.1.42:
  + Fully initialize fishes when loading from cache.
* Mon Jan 22 2018 luc14n0@linuxmail.org
- Update to version 0.1.40:
  + Added:
  - Format "CIE XYZ alpha" color model and formats;
  - Meson build; being tested in parallel with automake.
  + New API babl_process_rows for reduced overhead in some
    scenarios; though bigger gains seen also for regular
    babl_process with reimplemented branch-free dispatch, and
    faster cbrt.
  + Improved reference conversions for formats skipping some of
    models components.
  + Fixed gamma handling in indexed/palettized formats and improved
    gamma precision consistenct in sse2 conversions.
* Sun Dec 31 2017 jengelh@inai.de
- Fix RPM groups. Drop comment about author extraction (not used
  for specfiles in general anymore).
* Thu Dec 28 2017 zaitor@opensuse.org
- Update to version 0.1.38:
  + Added format "CIE L float", a couple of protections against
    division by 0.0.
- Changes from version 0.1.36:
  + Optimized customized primary aware code paths for CIE
    Lab<->RGB conversions, improved accuracy of gamma
    approximations.
  + New API babl_format_exists() for checking validity of babl
    format name, crash proofing of cache handling and use of
    environment variables.
* Sun Nov  5 2017 luc14n0@linuxmail.org
- Update to version 0.1.34:
  + Brown paper bag release
  + Fix indexed / custom primaries conflict
  + Re-export a symbol used by old GEGL/GIMPs
- Changes from version 0.1.32:
  + Added custom primaries and TRC support through ICC parsing
  + Improved float<->half performance
  + Rewrite of all conversions functions to adhere to new signature
* Thu Aug 24 2017 zaitor@opensuse.org
- Update to version 0.1.30:
  + Thread stability for palette modes, stricter alpha
    preservation, now cross-compilable on android.
* Tue Jul  4 2017 zaitor@opensuse.org
- Update to version 0.1.28:
  + Fast paths for Lav <-> Lch, release triggered by pending GIMP
    release.
* Thu May 18 2017 zaitor@opensuse.org
- Update to version 0.1.26:
  + Build and install HCY color space, platform independences fixes
    to fish cache.
* Sun Feb  5 2017 zaitor@opensuse.org
- Update to version 0.1.24:
  + Improvements to profile cache persistance, fast paths that
    improve actual GIMP use on various precisions, use single
    precision constants for some more of CIE computions.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 0.1.22:
  + Added cache of profiled conversions, added HCY color model,
    some precision and performance updated for fast paths.
- Changes from version 0.1.20:
  + Fix run-time errors, leaks, and race conditions. Add
    conditional fast paths.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 0.1.18:
  + Bugfix: take alpha threshold in consideration when processing
    floats in SSE2.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Fri Mar 11 2016 zaitor@opensuse.org
- Update to version 0.1.16:
  + Improvements to half float reference, SIMD, and fast-paths, and
    CIE float fast paths; cleanups of fast path extensions.
* Thu Nov 26 2015 zaitor@opensuse.org
- Update to version 0.1.14:
  + sRGB precision tuning
  + Stability fixes
  + Locale fix for setting error tolerance.
* Wed Feb 11 2015 zaitor@opensuse.org
- Drop vala, libtool and gobject-introspection-devel BuildRequires,
  they are no longer needed.
- Due to above changes, no longer define build_vala, stop passing
  autogen.sh to configure, nor --enable-introspection or
  - -without-vala.
- Drop typelib-1_0-Babl-0_1 Requires from devel package, it no
  longer exists.
* Sat Feb  7 2015 sfalken@opensuse.org
- Update to version 0.1.12:
  + optimizations for floating point conversions, HSV and HSL
    color models
  + removal of dead code
  + fixed CIE Lab conversions
- Patches Dropped:
  + babl-fix-gir-build.patch
  + babl-fix-gir.patch
  + Modified .spec to remove typelib package and gir-related %%files
  entries.  Package no longer provides them.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 0.1.10:
  + LUT based speedups for gamma correction / uncorrection.
- Changes from version 0.1.8:
  + Added support for indexed/pallette based formats.
  + Constified API.
- Pass --enable-introspection to configure to make sure we build
  introspection support.
- Add babl-fix-gir-build.patch: this fixes the build of
  introspection (as well as the generated data).
- Since the build of vala bindings is broken, temporarily disable
  it with a build_vala macro that helps us pass --without-vala to
  configure.
* Tue Jan 10 2012 dimstar@opensuse.org
- Add babl-fix-gir.patch: Fix building of the .gir and .typelib
  files.
- Add vala and gobject-introspection BuildRequires to build the
  introspection and vala support.
- Create typelib-1_0-Babl-0_1 subpackage for typelib.
- Add typelib-1_0-Babl-0_1 Requires to -devel package.
- Add libtool BuildRequires and call to autogen.sh as the patch
  babl-fix-gir.patch touches the build system.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 0.1.6:
  + Build improvements
  + Remove blatantly wrong conversions from extensions
  + Made it possible to distinguish format_n formats from others
  + Improvements to vala/gobject introspection support.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat Apr 16 2011 mrdocs@opensuse.org
- Update to version 0.1.4:
  + many build and autotool fixes
  + Add experimental introspection support - disabled by default
  + Add code to handle N-components.
* Mon May  3 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.1.2:
  + Made babl mostly threadsafe (sufficient for GIMP/GEGLs needs).
  + Streamlined core functionality, reducing number of function
    calls and removing overeager instrumentation.
- Drop babl-fix-install.patch: fixed upstream. The autoreconf call
  can also be removed.
- Rename libbabl-0_0-0 to libbabl-0_1-0, following soname change.
  This also means we can remove the Provides/Obsoletes for
  babl-0_0.
* Fri May 22 2009 vuntz@novell.com
- Update to version 0.1.0:
  + Support for RGBA representation in the frequency domain
  + Un-pre-multiply close-to-zero alpha values to complete black
    instead of slightly brighter than black
  + Add a BABL_ALPHA_THRESHOLD constantto the API
  + Do a complete overhaul of the babl API
  + Do some changes to increase portability of the library.
- Drop babl-undefined.patch: fixed upstream.
- Add babl-fix-install.patch to fix the build.
- Remove babl-0_0 package and make libbabl-0_0-0 provide/obsolete
  it.
- COPYING.lesser doesn't exist anymore. The package is LGPLv3+
  only (no more GPL).
* Mon Dec 15 2008 sbrabec@suse.cz
- Fixed undefined operation (bnc#449633).
* Wed Oct 22 2008 maw@suse.de
- Make debug packages require a specific %%{version}-%%{release}.
* Mon Sep  8 2008 dmueller@suse.de
- fix build
* Mon Jul 21 2008 sbrabec@suse.cz
- New SuSE package.
